@@ -1,3 +1,4 @@
+from __future__ import annotations
 from pathlib import Path
 from typing import Callable, List, Dict, Any, Union, Optional, TYPE_CHECKING, cast
 from copy import deepcopy
@@ -17,25 +18,28 @@ DATA_CHECK_PIPELINE_FILE = "data_check_pipeline.yml"
 
 
 class PipelineCheck(BaseCheck):
-    def __init__(self, data_check: "DataCheck", check_path: Path) -> None:
+    def __init__(self, data_check: DataCheck, check_path: Path) -> None:
         super().__init__(data_check, check_path)
         self.pipeline_steps: Dict[str, Dict[str, Any]] = {}
         self.register_pipelines()
 
     def register_pipelines(self):
         self.register_pipeline_step(
-            "load_tables",
+            "load",
             self.data_check.sql.table_loader.load_tables_from_files,
             convert_to_path_list=["files"],
         )
         self.register_pipeline_step(
-            "load",
+            "load_table",
             self.data_check.sql.table_loader.load_table_from_file,
             convert_to_path=["file"],
         )
         self.register_pipeline_step("cmd", self.run_cmd)
+
+        # pipeline checks should run with the same connection, so we do not clean them up
+        pipeline_check = partial(self.data_check.run, do_cleanup=False)
         self.register_pipeline_step(
-            "check", self.data_check.run, convert_to_path_list=["files"]
+            "check", pipeline_check, convert_to_path_list=["files"]
         )
         self.register_pipeline_step(
             "sql_files", self.data_check.run_sql_files, convert_to_path_list=["files"]
@@ -48,6 +52,12 @@ class PipelineCheck(BaseCheck):
         )
         self.register_pipeline_step("sql", pipeline_run_sql_query)
         self.register_pipeline_step("always_run", self.always_run)
+        self.register_pipeline_step(
+            "fake",
+            self.data_check.fake_data,
+            convert_to_path_list=["configs"],
+            convert_to_path=["output"],
+        )
 
     @staticmethod
     def is_check_path(path: Path) -> bool:
