@@ -5,6 +5,7 @@ from sqlalchemy.engine import Engine, Connection
 from sqlalchemy.engine.row import Row
 from sqlalchemy.engine.cursor import CursorResult
 from sqlalchemy.sql import text
+from sqlalchemy.sql.elements import TextClause
 from sqlalchemy.sql.expression import bindparam
 import pandas as pd
 from pathlib import Path
@@ -54,7 +55,7 @@ class DataCheckSql:
         """
         return {}  # no special parameters needed for now
 
-    def _keep_connection(self):
+    def keep_connection(self):
         # Do not keep the connection if runner has more than 1 workers.
         # Cannot pickle otherwise.
         return self.runner.workers == 1
@@ -68,7 +69,7 @@ class DataCheckSql:
                 path.expandvars(self.connection),
                 **{**self.get_db_params(), **extra_params},
             )
-            if self._keep_connection():
+            if self.keep_connection():
                 self.__engine = _engine
             else:
                 return _engine
@@ -77,12 +78,25 @@ class DataCheckSql:
     def get_connection(self) -> Connection:
         if self.__connection is None:
             _connection = self.get_engine().connect()
-            if self._keep_connection():
+            if self.keep_connection():
                 self.__connection = _connection
             else:
                 return _connection
         return self.__connection
 
+    def disconnect(self):
+        if self.__connection:
+            self.__connection.close()
+            self.__connection = None
+        if self.__engine:
+            self.__engine.dispose()
+            self.__engine = None
+
+    def __del__(self):
+        # __del__ is not always called when the object gets deleted,
+        # but when it does, we should disconnect cleanly.
+        self.disconnect()
+
     @property
     def dialect(self) -> str:
         return self.get_connection().dialect.name
@@ -93,14 +107,19 @@ class DataCheckSql:
         """
         return self.run_query_with_result(query, params=params).df
 
+    @staticmethod
+    def _bindparams(query: str) -> TextClause:
+        sql = text(query)
+        for bp in sql._bindparams.keys():
+            sql = sql.bindparams(bindparam(bp, expanding=True))
+        return sql
+
     def run_query_with_result(
         self, query: str, params: Dict[str, Any] = {}
     ) -> QueryResult:
         if not self.connection:
             raise DataCheckException(f"undefined connection: {self.connection}")
-        sql = text(query)
-        for bp in sql._bindparams.keys():
-            sql = sql.bindparams(bindparam(bp, expanding=True))
+        sql = self._bindparams(query)
 
         result = QueryResult(query, self.get_connection().execute(sql, **params))
         return result
@@ -121,18 +140,24 @@ class DataCheckSql:
             return False
 
     def run_sql(
-        self, query: str, output: Union[str, Path] = "", base_path: Path = Path(".")
+        self,
+        query: str,
+        output: Union[str, Path] = "",
+        params: Dict[str, Any] = {},
+        base_path: Path = Path("."),
     ):
-        sq_text = text(query)
+        sq_text = self._bindparams(query)
         result: CursorResult = self.get_connection().execute(
-            sq_text.execution_options(autocommit=True)
+            sq_text.execution_options(autocommit=True), **params
         )
         try:
             res: List[Row] = result.fetchall()
             columns: List[str] = result.keys()
             df = pd.DataFrame(data=res, columns=columns)
-            print_csv(df, self.output.print)
-            write_csv(df, output=output, base_path=base_path)
+            if output:
+                write_csv(df, output=output, base_path=base_path)
+            else:
+                print_csv(df, self.output.print)
             return res
         except Exception:
             return bool(result)
